@@ -8,7 +8,7 @@ use Log::Any qw($log);
 use POSIX qw(locale_h);
 use Text::sprintfn;
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # every type extension is registered here
 our %typex; # key = type, val = [clause, ...]
@@ -108,7 +108,11 @@ sub _ordinate {
     my ($self, $cd, $n, $noun) = @_;
 
     my $lang = $cd->{args}{lang};
-    if ($lang eq 'en_US') {
+
+    # we assume _xlt() has been called (and thus the appropriate
+    # Data::Sah::Lang::* has been loaded)
+
+    if ($lang eq 'en_US' || !$Data::Sah::Lang::{"$lang\::"}) {
         require Lingua::EN::Numbers::Ordinate;
         return Lingua::EN::Numbers::Ordinate::ordinate($n) . " $noun";
     }
@@ -493,7 +497,7 @@ Data::Sah::Compiler::human - Compile Sah schema to human language
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
